@@ -12,7 +12,7 @@ from numpy import loadtxt
 import pandas as pd
 import matplotlib
 import matplotlib.pyplot as plt
-from .electrochem import cycling_CCCV, cycling_data_processing,impedance_data_processing,Nyquist_plot,diff_cap,dis_cap
+from .electrochem import *
 
 import sklearn         
 from sklearn import linear_model, datasets
@@ -65,9 +65,9 @@ def EIS_to_cap_retention_off_gbr(filename):
     gbr_upper=joblib.load('data/gbr_upper_interval.sav')
     gbr_lower=joblib.load('data/gbr_lower_interval.sav')
     
-    y_pred = round(gbr.predict(Z)*100,2)
-    y_lower = round(gbr_lower.predict(Z)*100,2)
-    y_upper = round(gbr_upper.predict(Z)*100,2)
+    y_pred = round(gbr.predict(Z)[0]*100,2)
+    y_lower = round(gbr_lower.predict(Z)[0]*100,2)
+    y_upper = round(gbr_upper.predict(Z)[0]*100,2)
     
     return(y_pred,y_lower,y_upper)
 
@@ -122,9 +122,9 @@ def EIS_to_cap_retention_onl_gbr(filename,learning_rate , n_estimators, max_dept
     for alpha in [0.05,0.95]:
         gbr_int = GradientBoostingRegressor(loss="quantile", alpha=alpha, **common_params)
         confident_interval["q %1.2f" % alpha] = gbr_int.fit(X_train, y_train)
-    y_pred = round(gbr.predict(Z)*100,2)
-    y_lower = round(confident_interval["q 0.05"].predict(Z)*100,2)
-    y_upper = round(confident_interval["q 0.95"].predict(Z)*100,2)
+    y_pred = round(gbr.predict(Z)[0]*100,2)
+    y_lower = round(confident_interval["q 0.05"].predict(Z)[0]*100,2)
+    y_upper = round(confident_interval["q 0.95"].predict(Z)[0]*100,2)
     return(y_pred,y_lower,y_upper)
     
 def EIS_to_cap_retention_off_rdf(filename):
@@ -154,8 +154,8 @@ def EIS_to_cap_retention_off_rdf(filename):
     Z=Z.reshape(1, -1)
     rdf=joblib.load('data/rdf_model.sav')
    
-    return(round(rdf.predict(Z)*100,2))
-
+    # return(round(rdf.predict(Z)[0]*100,2))
+    return(round(rdf.predict(Z)[0]*100,2))
 
 
 def EIS_to_cap_retention_onl_rdf(filename,n_estimators,max_features):
@@ -195,7 +195,7 @@ def EIS_to_cap_retention_onl_rdf(filename,n_estimators,max_features):
     
     clf_random = RandomForestRegressor(n_estimators=n_estimators, random_state=10,max_features=max_features)
     clf_random = clf_random.fit(X_train, y_train)
-    return(round(clf_random.predict(Z)*100,2))
+    return(round(clf_random.predict(Z)[0]*100,2))
  
     
     
